@@ -1,27 +1,26 @@
 """
-    MIT License
+MIT License
 
-    Copyright (c) 2022 kian Ahmadian
+Copyright (c) 2023 Kian Ahmadian
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
 
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
-
 from __future__ import annotations
 import asyncio
 from typing import Callable, Dict, Tuple, List, Optional
@@ -772,6 +771,37 @@ class Bot:
         response = await self.http.get_chat_administrators(chat.chat_id)
         return [ChatMember.from_dict(data=member_payload) for member_payload in response.result or list()]
 
+    async def download_file(self, file_id: str):
+        """
+        .. warning::
+            You must be entered `chat` or `chat_id`
+
+        Parameters
+        ----------
+            file_id: :class:`str`
+                    file id
+
+        Returns
+        -------
+            Optional[:class:`bytes`]:
+                The content of the file
+
+        Raises
+        ------
+            NotFound
+                Invalid file ID.
+            Forbidden
+                You do not have permission to download File.
+            APIError
+                download File Failed.
+        """
+        if not isinstance(file_id, str):
+            raise TypeError(
+                "file_id must be type of str"
+            )
+
+        return await self.http.get_file(file_id)
+
     async def get_updates(self, offset: int = None, limit: int = None) -> list["Update"] | None:
         if offset and not isinstance(offset, int):
             raise TypeError(
